@@ -38,8 +38,9 @@ class StreamSeaConnection:
     async def __aenter__(self):
         return await self
 
-    async def __aexit__(self):
-        pass # TODO
+    async def __aexit__(self, exc_type, exc_value, traceback):
+        ws = await self.ensure_ws
+        await ws.close()
 
     def __await__(self):
         # Create a suitable iterator by calling __await__ on a coroutine.
@@ -86,7 +87,6 @@ class StreamSeaConnection:
     
     async def authenticated_listen(self):
         # Receive messages forever
-        print('Listening for messages')
         while True:
             r = await self.recv()
             await self.on_authenticated_message(r)
@@ -124,7 +124,6 @@ class StreamSeaConnection:
     # Callback for every message after the authentication phase
     # TODO: does this need to be async?
     async def on_authenticated_message(self, message):
-        # print('on_authenticated_message: ', message)
         try:
             message_json = json.loads(message)
             if 'id' not in message_json:
